import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { ConfirmProductInstanceRequest, ConfirmProductInstanceResult } from "../models/models_0";
/**
 * The input for {@link ConfirmProductInstanceCommand}.
 */
export interface ConfirmProductInstanceCommandInput extends ConfirmProductInstanceRequest {
}
/**
 * The output of {@link ConfirmProductInstanceCommand}.
 */
export interface ConfirmProductInstanceCommandOutput extends ConfirmProductInstanceResult, __MetadataBearer {
}
/**
 * <p>Determines whether a product code is associated with an instance. This action can only
 *             be used by the owner of the product code. It is useful when a product code owner must
 *             verify whether another user's instance is eligible for support.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, ConfirmProductInstanceCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, ConfirmProductInstanceCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new ConfirmProductInstanceCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ConfirmProductInstanceCommandInput} for command's `input` shape.
 * @see {@link ConfirmProductInstanceCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 * @example To confirm the product instance
 * ```javascript
 * // This example determines whether the specified product code is associated with the specified instance.
 * const input = {
 *   "InstanceId": "i-1234567890abcdef0",
 *   "ProductCode": "774F4FF8"
 * };
 * const command = new ConfirmProductInstanceCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "OwnerId": "123456789012"
 * }
 * *\/
 * // example id: to-confirm-the-product-instance-1472712108494
 * ```
 *
 */
export declare class ConfirmProductInstanceCommand extends $Command<ConfirmProductInstanceCommandInput, ConfirmProductInstanceCommandOutput, EC2ClientResolvedConfig> {
    readonly input: ConfirmProductInstanceCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: ConfirmProductInstanceCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ConfirmProductInstanceCommandInput, ConfirmProductInstanceCommandOutput>;
    private serialize;
    private deserialize;
}
