import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { DescribeImagesRequest, DescribeImagesResult } from "../models/models_3";
/**
 * The input for {@link DescribeImagesCommand}.
 */
export interface DescribeImagesCommandInput extends DescribeImagesRequest {
}
/**
 * The output of {@link DescribeImagesCommand}.
 */
export interface DescribeImagesCommandOutput extends DescribeImagesResult, __MetadataBearer {
}
/**
 * <p>Describes the specified images (AMIs, AKIs, and ARIs) available to you or all of the images available to you.</p>
 *          <p>The images available to you include public images, private images that you own, and private images owned by other
 *        Amazon Web Services accounts for which you have explicit launch permissions.</p>
 *          <p>Recently deregistered images appear in the returned results for a short interval and then
 *       return empty results. After all instances that reference a deregistered AMI are terminated,
 *       specifying the ID of the image will eventually return an error indicating that the AMI ID
 *       cannot be found.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DescribeImagesCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DescribeImagesCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new DescribeImagesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeImagesCommandInput} for command's `input` shape.
 * @see {@link DescribeImagesCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 * @example To describe an AMI
 * ```javascript
 * // This example describes the specified AMI.
 * const input = {
 *   "ImageIds": [
 *     "ami-5731123e"
 *   ]
 * };
 * const command = new DescribeImagesCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "Images": [
 *     {
 *       "Architecture": "x86_64",
 *       "BlockDeviceMappings": [
 *         {
 *           "DeviceName": "/dev/sda1",
 *           "Ebs": {
 *             "DeleteOnTermination": true,
 *             "SnapshotId": "snap-1234567890abcdef0",
 *             "VolumeSize": 8,
 *             "VolumeType": "standard"
 *           }
 *         }
 *       ],
 *       "Description": "An AMI for my server",
 *       "Hypervisor": "xen",
 *       "ImageId": "ami-5731123e",
 *       "ImageLocation": "123456789012/My server",
 *       "ImageType": "machine",
 *       "KernelId": "aki-88aa75e1",
 *       "Name": "My server",
 *       "OwnerId": "123456789012",
 *       "Public": false,
 *       "RootDeviceName": "/dev/sda1",
 *       "RootDeviceType": "ebs",
 *       "State": "available",
 *       "VirtualizationType": "paravirtual"
 *     }
 *   ]
 * }
 * *\/
 * // example id: to-describe-an-ami-1529025482866
 * ```
 *
 */
export declare class DescribeImagesCommand extends $Command<DescribeImagesCommandInput, DescribeImagesCommandOutput, EC2ClientResolvedConfig> {
    readonly input: DescribeImagesCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: DescribeImagesCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeImagesCommandInput, DescribeImagesCommandOutput>;
    private serialize;
    private deserialize;
}
