import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { DescribeRegionsRequest, DescribeRegionsResult } from "../models/models_4";
/**
 * The input for {@link DescribeRegionsCommand}.
 */
export interface DescribeRegionsCommandInput extends DescribeRegionsRequest {
}
/**
 * The output of {@link DescribeRegionsCommand}.
 */
export interface DescribeRegionsCommandOutput extends DescribeRegionsResult, __MetadataBearer {
}
/**
 * <p>Describes the Regions that are enabled for your account, or all Regions.</p>
 *          <p>For a list of the Regions supported by Amazon EC2, see <a href="https://docs.aws.amazon.com/general/latest/gr/ec2-service.html">
 *        Amazon Elastic Compute Cloud endpoints and quotas</a>.</p>
 *          <p>For information about enabling and disabling Regions for your account, see <a href="https://docs.aws.amazon.com/general/latest/gr/rande-manage.html">Managing Amazon Web Services Regions</a> in the <i>Amazon Web Services General Reference</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DescribeRegionsCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DescribeRegionsCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new DescribeRegionsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeRegionsCommandInput} for command's `input` shape.
 * @see {@link DescribeRegionsCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 * @example To describe your regions
 * ```javascript
 * // This example describes all the regions that are available to you.
 * const input = undefined;
 * const command = new DescribeRegionsCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "Regions": [
 *     {
 *       "Endpoint": "ec2.ap-south-1.amazonaws.com",
 *       "RegionName": "ap-south-1"
 *     },
 *     {
 *       "Endpoint": "ec2.eu-west-1.amazonaws.com",
 *       "RegionName": "eu-west-1"
 *     },
 *     {
 *       "Endpoint": "ec2.ap-southeast-1.amazonaws.com",
 *       "RegionName": "ap-southeast-1"
 *     },
 *     {
 *       "Endpoint": "ec2.ap-southeast-2.amazonaws.com",
 *       "RegionName": "ap-southeast-2"
 *     },
 *     {
 *       "Endpoint": "ec2.eu-central-1.amazonaws.com",
 *       "RegionName": "eu-central-1"
 *     },
 *     {
 *       "Endpoint": "ec2.ap-northeast-2.amazonaws.com",
 *       "RegionName": "ap-northeast-2"
 *     },
 *     {
 *       "Endpoint": "ec2.ap-northeast-1.amazonaws.com",
 *       "RegionName": "ap-northeast-1"
 *     },
 *     {
 *       "Endpoint": "ec2.us-east-1.amazonaws.com",
 *       "RegionName": "us-east-1"
 *     },
 *     {
 *       "Endpoint": "ec2.sa-east-1.amazonaws.com",
 *       "RegionName": "sa-east-1"
 *     },
 *     {
 *       "Endpoint": "ec2.us-west-1.amazonaws.com",
 *       "RegionName": "us-west-1"
 *     },
 *     {
 *       "Endpoint": "ec2.us-west-2.amazonaws.com",
 *       "RegionName": "us-west-2"
 *     }
 *   ]
 * }
 * *\/
 * // example id: ec2-describe-regions-1
 * ```
 *
 */
export declare class DescribeRegionsCommand extends $Command<DescribeRegionsCommandInput, DescribeRegionsCommandOutput, EC2ClientResolvedConfig> {
    readonly input: DescribeRegionsCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: DescribeRegionsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeRegionsCommandInput, DescribeRegionsCommandOutput>;
    private serialize;
    private deserialize;
}
