import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { DescribeScheduledInstanceAvailabilityRequest, DescribeScheduledInstanceAvailabilityResult } from "../models/models_4";
/**
 * The input for {@link DescribeScheduledInstanceAvailabilityCommand}.
 */
export interface DescribeScheduledInstanceAvailabilityCommandInput extends DescribeScheduledInstanceAvailabilityRequest {
}
/**
 * The output of {@link DescribeScheduledInstanceAvailabilityCommand}.
 */
export interface DescribeScheduledInstanceAvailabilityCommandOutput extends DescribeScheduledInstanceAvailabilityResult, __MetadataBearer {
}
/**
 * <p>Finds available schedules that meet the specified criteria.</p>
 *          <p>You can search for an available schedule no more than 3 months in advance. You must meet the minimum required duration of 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours.</p>
 *          <p>After you find a schedule that meets your needs, call <a>PurchaseScheduledInstances</a>
 *          to purchase Scheduled Instances with that schedule.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DescribeScheduledInstanceAvailabilityCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DescribeScheduledInstanceAvailabilityCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new DescribeScheduledInstanceAvailabilityCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeScheduledInstanceAvailabilityCommandInput} for command's `input` shape.
 * @see {@link DescribeScheduledInstanceAvailabilityCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 * @example To describe an available schedule
 * ```javascript
 * // This example describes a schedule that occurs every week on Sunday, starting on the specified date. Note that the output contains a single schedule as an example.
 * const input = {
 *   "FirstSlotStartTimeRange": {
 *     "EarliestTime": "2016-01-31T00:00:00Z",
 *     "LatestTime": "2016-01-31T04:00:00Z"
 *   },
 *   "Recurrence": {
 *     "Frequency": "Weekly",
 *     "Interval": 1,
 *     "OccurrenceDays": [
 *       1
 *     ]
 *   }
 * };
 * const command = new DescribeScheduledInstanceAvailabilityCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "ScheduledInstanceAvailabilitySet": [
 *     {
 *       "AvailabilityZone": "us-west-2b",
 *       "AvailableInstanceCount": 20,
 *       "FirstSlotStartTime": "2016-01-31T00:00:00Z",
 *       "HourlyPrice": "0.095",
 *       "InstanceType": "c4.large",
 *       "MaxTermDurationInDays": 366,
 *       "MinTermDurationInDays": 366,
 *       "NetworkPlatform": "EC2-VPC",
 *       "Platform": "Linux/UNIX",
 *       "PurchaseToken": "eyJ2IjoiMSIsInMiOjEsImMiOi...",
 *       "Recurrence": {
 *         "Frequency": "Weekly",
 *         "Interval": 1,
 *         "OccurrenceDaySet": [
 *           1
 *         ],
 *         "OccurrenceRelativeToEnd": false
 *       },
 *       "SlotDurationInHours": 23,
 *       "TotalScheduledInstanceHours": 1219
 *     }
 *   ]
 * }
 * *\/
 * // example id: ec2-describe-scheduled-instance-availability-1
 * ```
 *
 */
export declare class DescribeScheduledInstanceAvailabilityCommand extends $Command<DescribeScheduledInstanceAvailabilityCommandInput, DescribeScheduledInstanceAvailabilityCommandOutput, EC2ClientResolvedConfig> {
    readonly input: DescribeScheduledInstanceAvailabilityCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: DescribeScheduledInstanceAvailabilityCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeScheduledInstanceAvailabilityCommandInput, DescribeScheduledInstanceAvailabilityCommandOutput>;
    private serialize;
    private deserialize;
}
