import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { DescribeScheduledInstancesRequest, DescribeScheduledInstancesResult } from "../models/models_4";
/**
 * The input for {@link DescribeScheduledInstancesCommand}.
 */
export interface DescribeScheduledInstancesCommandInput extends DescribeScheduledInstancesRequest {
}
/**
 * The output of {@link DescribeScheduledInstancesCommand}.
 */
export interface DescribeScheduledInstancesCommandOutput extends DescribeScheduledInstancesResult, __MetadataBearer {
}
/**
 * <p>Describes the specified Scheduled Instances or all your Scheduled Instances.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DescribeScheduledInstancesCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DescribeScheduledInstancesCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new DescribeScheduledInstancesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeScheduledInstancesCommandInput} for command's `input` shape.
 * @see {@link DescribeScheduledInstancesCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 * @example To describe your Scheduled Instances
 * ```javascript
 * // This example describes the specified Scheduled Instance.
 * const input = {
 *   "ScheduledInstanceIds": [
 *     "sci-1234-1234-1234-1234-123456789012"
 *   ]
 * };
 * const command = new DescribeScheduledInstancesCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "ScheduledInstanceSet": [
 *     {
 *       "AvailabilityZone": "us-west-2b",
 *       "CreateDate": "2016-01-25T21:43:38.612Z",
 *       "HourlyPrice": "0.095",
 *       "InstanceCount": 1,
 *       "InstanceType": "c4.large",
 *       "NetworkPlatform": "EC2-VPC",
 *       "NextSlotStartTime": "2016-01-31T09:00:00Z",
 *       "Platform": "Linux/UNIX",
 *       "Recurrence": {
 *         "Frequency": "Weekly",
 *         "Interval": 1,
 *         "OccurrenceDaySet": [
 *           1
 *         ],
 *         "OccurrenceRelativeToEnd": false,
 *         "OccurrenceUnit": ""
 *       },
 *       "ScheduledInstanceId": "sci-1234-1234-1234-1234-123456789012",
 *       "SlotDurationInHours": 32,
 *       "TermEndDate": "2017-01-31T09:00:00Z",
 *       "TermStartDate": "2016-01-31T09:00:00Z",
 *       "TotalScheduledInstanceHours": 1696
 *     }
 *   ]
 * }
 * *\/
 * // example id: ec2-describe-scheduled-instances-1
 * ```
 *
 */
export declare class DescribeScheduledInstancesCommand extends $Command<DescribeScheduledInstancesCommandInput, DescribeScheduledInstancesCommandOutput, EC2ClientResolvedConfig> {
    readonly input: DescribeScheduledInstancesCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: DescribeScheduledInstancesCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeScheduledInstancesCommandInput, DescribeScheduledInstancesCommandOutput>;
    private serialize;
    private deserialize;
}
