import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { DescribeSpotPriceHistoryRequest, DescribeSpotPriceHistoryResult } from "../models/models_4";
/**
 * The input for {@link DescribeSpotPriceHistoryCommand}.
 */
export interface DescribeSpotPriceHistoryCommandInput extends DescribeSpotPriceHistoryRequest {
}
/**
 * The output of {@link DescribeSpotPriceHistoryCommand}.
 */
export interface DescribeSpotPriceHistoryCommandOutput extends DescribeSpotPriceHistoryResult, __MetadataBearer {
}
/**
 * <p>Describes the Spot price history. For more information, see <a href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-spot-instances-history.html">Spot Instance pricing history</a> in the
 *             <i>Amazon EC2 User Guide for Linux Instances</i>.</p>
 *          <p>When you specify a start and end time, the operation returns the prices of the
 *             instance types within that time range. It also returns the last price change before the
 *             start time, which is the effective price as of the start time.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DescribeSpotPriceHistoryCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DescribeSpotPriceHistoryCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new DescribeSpotPriceHistoryCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DescribeSpotPriceHistoryCommandInput} for command's `input` shape.
 * @see {@link DescribeSpotPriceHistoryCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 * @example To describe Spot price history for Linux/UNIX (Amazon VPC)
 * ```javascript
 * // This example returns the Spot Price history for m1.xlarge, Linux/UNIX (Amazon VPC) instances for a particular day in January.
 * const input = {
 *   "EndTime": "2014-01-06T08:09:10",
 *   "InstanceTypes": [
 *     "m1.xlarge"
 *   ],
 *   "ProductDescriptions": [
 *     "Linux/UNIX (Amazon VPC)"
 *   ],
 *   "StartTime": "2014-01-06T07:08:09"
 * };
 * const command = new DescribeSpotPriceHistoryCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "SpotPriceHistory": [
 *     {
 *       "AvailabilityZone": "us-west-1a",
 *       "InstanceType": "m1.xlarge",
 *       "ProductDescription": "Linux/UNIX (Amazon VPC)",
 *       "SpotPrice": "0.080000",
 *       "Timestamp": "2014-01-06T04:32:53.000Z"
 *     },
 *     {
 *       "AvailabilityZone": "us-west-1c",
 *       "InstanceType": "m1.xlarge",
 *       "ProductDescription": "Linux/UNIX (Amazon VPC)",
 *       "SpotPrice": "0.080000",
 *       "Timestamp": "2014-01-05T11:28:26.000Z"
 *     }
 *   ]
 * }
 * *\/
 * // example id: ec2-describe-spot-price-history-1
 * ```
 *
 */
export declare class DescribeSpotPriceHistoryCommand extends $Command<DescribeSpotPriceHistoryCommandInput, DescribeSpotPriceHistoryCommandOutput, EC2ClientResolvedConfig> {
    readonly input: DescribeSpotPriceHistoryCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: DescribeSpotPriceHistoryCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DescribeSpotPriceHistoryCommandInput, DescribeSpotPriceHistoryCommandOutput>;
    private serialize;
    private deserialize;
}
