import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { DisassociateNatGatewayAddressRequest, DisassociateNatGatewayAddressResult } from "../models/models_5";
/**
 * The input for {@link DisassociateNatGatewayAddressCommand}.
 */
export interface DisassociateNatGatewayAddressCommandInput extends DisassociateNatGatewayAddressRequest {
}
/**
 * The output of {@link DisassociateNatGatewayAddressCommand}.
 */
export interface DisassociateNatGatewayAddressCommandOutput extends DisassociateNatGatewayAddressResult, __MetadataBearer {
}
/**
 * <p>Disassociates secondary Elastic IP addresses (EIPs) from a public NAT gateway. You cannot disassociate your primary EIP. For more information, see <a href="https://docs.aws.amazon.com/vpc/latest/userguide/vpc-nat-gateway.html#nat-gateway-edit-secondary">Edit secondary IP address associations</a> in the <i>Amazon Virtual Private Cloud User Guide</i>.</p>
 *          <p>While disassociating is in progress, you cannot associate/disassociate additional EIPs while the connections are being drained. You are, however, allowed to delete the NAT gateway.</p>
 *          <p>An EIP will only be released at the end of MaxDrainDurationSeconds. The EIPs stay
 *             associated and support the existing connections but do not support any new connections
 *             (new connections are distributed across the remaining associated EIPs). As the existing
 *             connections drain out, the EIPs (and the corresponding private IPs mapped to them) get
 *             released.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, DisassociateNatGatewayAddressCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, DisassociateNatGatewayAddressCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new DisassociateNatGatewayAddressCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link DisassociateNatGatewayAddressCommandInput} for command's `input` shape.
 * @see {@link DisassociateNatGatewayAddressCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 */
export declare class DisassociateNatGatewayAddressCommand extends $Command<DisassociateNatGatewayAddressCommandInput, DisassociateNatGatewayAddressCommandOutput, EC2ClientResolvedConfig> {
    readonly input: DisassociateNatGatewayAddressCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: DisassociateNatGatewayAddressCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<DisassociateNatGatewayAddressCommandInput, DisassociateNatGatewayAddressCommandOutput>;
    private serialize;
    private deserialize;
}
