import { EndpointParameterInstructions } from "@aws-sdk/middleware-endpoint";
import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { EC2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../EC2Client";
import { GetNetworkInsightsAccessScopeAnalysisFindingsRequest, GetNetworkInsightsAccessScopeAnalysisFindingsResult } from "../models/models_5";
/**
 * The input for {@link GetNetworkInsightsAccessScopeAnalysisFindingsCommand}.
 */
export interface GetNetworkInsightsAccessScopeAnalysisFindingsCommandInput extends GetNetworkInsightsAccessScopeAnalysisFindingsRequest {
}
/**
 * The output of {@link GetNetworkInsightsAccessScopeAnalysisFindingsCommand}.
 */
export interface GetNetworkInsightsAccessScopeAnalysisFindingsCommandOutput extends GetNetworkInsightsAccessScopeAnalysisFindingsResult, __MetadataBearer {
}
/**
 * <p>Gets the findings for the specified Network Access Scope analysis.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { EC2Client, GetNetworkInsightsAccessScopeAnalysisFindingsCommand } from "@aws-sdk/client-ec2"; // ES Modules import
 * // const { EC2Client, GetNetworkInsightsAccessScopeAnalysisFindingsCommand } = require("@aws-sdk/client-ec2"); // CommonJS import
 * const client = new EC2Client(config);
 * const command = new GetNetworkInsightsAccessScopeAnalysisFindingsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link GetNetworkInsightsAccessScopeAnalysisFindingsCommandInput} for command's `input` shape.
 * @see {@link GetNetworkInsightsAccessScopeAnalysisFindingsCommandOutput} for command's `response` shape.
 * @see {@link EC2ClientResolvedConfig | config} for EC2Client's `config` shape.
 *
 *
 */
export declare class GetNetworkInsightsAccessScopeAnalysisFindingsCommand extends $Command<GetNetworkInsightsAccessScopeAnalysisFindingsCommandInput, GetNetworkInsightsAccessScopeAnalysisFindingsCommandOutput, EC2ClientResolvedConfig> {
    readonly input: GetNetworkInsightsAccessScopeAnalysisFindingsCommandInput;
    static getEndpointParameterInstructions(): EndpointParameterInstructions;
    constructor(input: GetNetworkInsightsAccessScopeAnalysisFindingsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: EC2ClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetNetworkInsightsAccessScopeAnalysisFindingsCommandInput, GetNetworkInsightsAccessScopeAnalysisFindingsCommandOutput>;
    private serialize;
    private deserialize;
}
