import { QueryParameterBag } from "@aws-sdk/types";
/**
 * Creates a proxy to a {@link URLSearchParams} object that can be used like
 * a {@link QueryParameterBag} object. Modifying the proxy object modifies
 * the underlying {@link URLSearchParams} object.
 *
 * @param searchParams {@link URLSearchParams} to proxy.
 * @returns Proxy to the given {@link URLSearchParams} object.
 * @internal To \@aws-sdk/protocol-http package.
 */
export declare const getQueryProxy: (searchParams: URLSearchParams) => QueryParameterBag;
/**
 * Creates a new {@link URLSearchParams} populated with the query parameters
 * in the given {@link QueryParameterBag}. Ignores non-string values.
 *
 * @param query Query parameters to get as {@link URLSearchParams}.
 * @returns A {@link URLSearchParams} populated with the given query parameters.
 * @internal To \@aws-sdk/protocol-http package.
 */
export declare const queryToSearchParams: (query: QueryParameterBag) => URLSearchParams;
/**
 * Creates a new {@link QueryParameterBag} populated with the query parameters
 * in the given {@link URLSearchParams}.
 *
 * @param searchParams {@link URLSearchParams} to get as {@link QueryParameterBag}.
 * @returns A {@link QueryParameterBag} populated with the given query parameters.
 * @internal To \@aws-sdk/protocol-http package.
 */
export declare const searchParamsToQuery: (searchParams: URLSearchParams) => QueryParameterBag;
